summaryrefslogtreecommitdiff
path: root/libopie2/opiebluez/obluetooth.h
Side-by-side diff
Diffstat (limited to 'libopie2/opiebluez/obluetooth.h') (more/less context) (ignore whitespace changes)
-rw-r--r--libopie2/opiebluez/obluetooth.h40
1 files changed, 39 insertions, 1 deletions
diff --git a/libopie2/opiebluez/obluetooth.h b/libopie2/opiebluez/obluetooth.h
index 4423a55..ee4a90d 100644
--- a/libopie2/opiebluez/obluetooth.h
+++ b/libopie2/opiebluez/obluetooth.h
@@ -39,2 +39,3 @@ namespace Bluez {
class OBluetoothInterface;
+class OBluetoothDevice;
@@ -106,3 +107,3 @@ class OBluetooth : public QObject
*
* This class provides a wrapper for an infrared interface. All the cumbersome details of
* Linux ioctls are hidden under a convenient high-level interface.
@@ -115,2 +116,7 @@ class OBluetoothInterface : public QObject
{
+ Q_OBJECT
+ public:
+ typedef QDict<OBluetoothDevice> DeviceMap;
+ typedef QDictIterator<OBluetoothDevice> DeviceIterator;
+
public:
@@ -137,4 +143,9 @@ class OBluetoothInterface : public QObject
bool isUp() const;
+ /**
+ * @returns an iterator usable for iterating through the devices in range
+ */
+ DeviceIterator neighbourhood();
private:
+ DeviceMap _devices;
class Private;
@@ -143,3 +154,30 @@ class OBluetoothInterface : public QObject
+/*======================================================================================
+ * OBluetoothDevice
+ *======================================================================================*/
+
+/**
+ * @brief An bluetooth (remote) device abstraction.
+ *
+ * This class resembles a (remote) bluetooth device.
+ * @author Michael 'Mickey' Lauer <mickey@vanille.de>
+ */
+class OBluetoothDevice : public QObject
+{
+ Q_OBJECT
+ public:
+ /**
+ * Constructor.
+ */
+ OBluetoothDevice( QObject* parent, const char* name );
+ /**
+ * Destructor.
+ */
+ virtual ~OBluetoothDevice();
+ /**
+ * @returns the MAC address of the device's interface
+ */
+ QString macAddress() const;
+};
@@ -106,3 +107,3 @@ class OBluetooth : public QObject
*
- * This class provides a wrapper for an infrared interface. All the cumbersome details of
+ * This class provides a wrapper for a bluetooth HCI device. All the cumbersome details of
* Linux ioctls are hidden under a convenient high-level interface.